@@ -6,6 +6,7 @@ api blueprints group
 from sanic import Blueprint
 
 from python_signal_cli_rest_api.api.about import about_v1
+from python_signal_cli_rest_api.api.configuration import configuration_v1
 from python_signal_cli_rest_api.api.groups import (
     create_group_v1,
     delete_group_v1,
@@ -23,6 +24,7 @@ from python_signal_cli_rest_api.api.send import send_v1, send_v2
 
 entrypoint = Blueprint.group(
     about_v1,
+    configuration_v1,
     create_group_v1,
     delete_group_v1,
     groups_for_number_v1,
