@@ -5,10 +5,11 @@ helpers
 from base64 import b64decode
 from io import BytesIO
 from mimetypes import guess_extension
+from re import search as re_search
 from re import sub as re_sub
 from tempfile import mkstemp
 
-from jmespath import search
+from jmespath import search as j_search
 from magic import from_buffer
 from sanic.log import logger
 
@@ -35,20 +36,25 @@ def validate_recipients(recipients: list, number: str, version: int = 2):
     try:
         _, group_ids = get_groups(number=number)
     except Exception as exc:
-        raise Exception(f"Unable to list groups for {number}") from exc
+        raise Exception(f"Unable to fetch groups for {number}") from exc
     for recipient in recipients:
         if version == 1:
             recipient = recipient.replace("_", "/")
-        if search(f"[?id==`{recipient}`]", group_ids):
+        if j_search(f"[?id==`{recipient}`]", group_ids):
             groups.append(recipient)
             continue
+        if re_search("[a-zA-Z/=]", recipient):
+            unknown.append(recipient)
+            continue
         check_registered.append(recipient)
     try:
         registered = is_registered(recipients=check_registered, number=number)
     except Exception as exc:
-        raise Exception("Unable to check registered recipients") from exc
+        raise Exception(
+            "Unable to fetch network registration status for recipients"
+        ) from exc
     for recipient in check_registered:
-        if search(f"[?number==`{recipient}`]", registered):
+        if j_search(f"[?number==`{recipient}`]", registered):
             contacts.append(recipient)
             continue
         unknown.append(recipient)
@@ -76,7 +82,7 @@ def is_registered(recipients: list, number: str):
             },
         }
     )
-    return search(
+    return j_search(
         "[?isRegistered].{number: number, registered: isRegistered}", res.get("result")
     )
 
@@ -115,7 +121,7 @@ def get_groups(number: str, groupid: str = ""):
             }
         ).get("result", [])
         if groupid:
-            match = search(f"[?id==`{groupid}`]", groups)
+            match = j_search(f"[?id==`{groupid}`]", groups)
             if match:
                 return (True, get_group_response(match[0]))
         result = []
